/***************************************************************************

    Irem audio interface

****************************************************************************/

MACHINE_DRIVER_EXTERN( m52_sound_c_audio );
MACHINE_DRIVER_EXTERN( m52_large_audio );
MACHINE_DRIVER_EXTERN( m62_audio );

WRITE8_HANDLER( irem_sound_cmd_w );
